@@ -67,8 +67,8 @@ Experimental
 
 Starting with IPython 6.0, this module can make use of the Jedi library to
 generate completions both using static analysis of the code, and dynamically
-inspecting multiple namespaces. Jedi is an autocompletion and static analysis 
-for Python. The APIs attached to this new mechanism is unstable and will 
+inspecting multiple namespaces. Jedi is an autocompletion and static analysis
+for Python. The APIs attached to this new mechanism is unstable and will
 raise unless use in an :any:`provisionalcompleter` context manager.
 
 You will find that the following are experimental:
@@ -185,11 +185,11 @@ def provisionalcompleter(action='ignore'):
     """
 
 
-    This contest manager has to be used in any place where unstable completer
+    This context manager has to be used in any place where unstable completer
     behavior and API may be called.
 
     >>> with provisionalcompleter():
-    ...     completer.do_experimetal_things() # works
+    ...     completer.do_experimental_things() # works
 
     >>> completer.do_experimental_things() # raises.
 
@@ -198,12 +198,11 @@ def provisionalcompleter(action='ignore'):
         By using this context manager you agree that the API in use may change
         without warning, and that you won't complain if they do so.
 
-        You also understand that if the API is not to you liking you should report
-        a bug to explain your use case upstream and improve the API and will loose
-        credibility if you complain after the API is make stable.
+        You also understand that, if the API is not to your liking, you should report
+        a bug to explain your use case upstream.
 
-        We'll be happy to get your feedback , feature request and improvement on
-        any of the unstable APIs !
+        We'll be happy to get your feedback, feature requests, and improvements on
+        any of the unstable APIs!
     """
     with warnings.catch_warnings():
         warnings.filterwarnings(action, category=ProvisionalCompleterWarning)
@@ -1138,12 +1137,12 @@ class IPCompleter(Completer):
 
     def all_completions(self, text) -> List[str]:
         """
-        Wrapper around the completions method for the benefit of emacs.
+        Wrapper around the completion methods for the benefit of emacs.
         """
-        prefix = text[:text.rfind(".") + 1]
+        prefix = text.rpartition('.')[0]
         with provisionalcompleter():
-            return list(map(lambda c: prefix + c.text,
-                   self.completions(text, len(text))))
+            return ['.'.join([prefix, c.text]) if prefix and self.use_jedi else c.text
+                    for c in self.completions(text, len(text))]
 
         return self.complete(text)[1]
 
@@ -1557,7 +1556,7 @@ class IPCompleter(Completer):
                     argMatches.append(u"%s=" %namedArg)
         except:
             pass
-            
+
         return argMatches
 
     def dict_key_matches(self, text):
@@ -2015,7 +2014,7 @@ class IPCompleter(Completer):
 
         # Start with a clean slate of completions
         matches = []
-        custom_res = self.dispatch_custom_completer(text)
+        
         # FIXME: we should extend our api to return a dict with completions for
         # different types of objects.  The rlcomplete() method could then
         # simply collapse the dict into a list for readline, but we'd have
@@ -2026,29 +2025,24 @@ class IPCompleter(Completer):
                 full_text = line_buffer
             completions = self._jedi_matches(
                 cursor_pos, cursor_line, full_text)
-        if custom_res is not None:
-            # did custom completers produce something?
-            matches = [(m, 'custom') for m in custom_res]
+                
+        if self.merge_completions:
+            matches = []
+            for matcher in self.matchers:
+                try:
+                    matches.extend([(m, matcher.__qualname__)
+                                    for m in matcher(text)])
+                except:
+                    # Show the ugly traceback if the matcher causes an
+                    # exception, but do NOT crash the kernel!
+                    sys.excepthook(*sys.exc_info())
         else:
-            # Extend the list of completions with the results of each
-            # matcher, so we return results to the user from all
-            # namespaces.
-            if self.merge_completions:
-                matches = []
-                for matcher in self.matchers:
-                    try:
-                        matches.extend([(m, matcher.__qualname__)
-                                        for m in matcher(text)])
-                    except:
-                        # Show the ugly traceback if the matcher causes an
-                        # exception, but do NOT crash the kernel!
-                        sys.excepthook(*sys.exc_info())
-            else:
-                for matcher in self.matchers:
-                    matches = [(m, matcher.__qualname__)
-                               for m in matcher(text)]
-                    if matches:
-                        break
+            for matcher in self.matchers:
+                matches = [(m, matcher.__qualname__)
+                            for m in matcher(text)]
+                if matches:
+                    break
+                    
         seen = set()
         filtered_matches = set()
         for m in matches:
@@ -2057,10 +2051,13 @@ class IPCompleter(Completer):
                 filtered_matches.add(m)
                 seen.add(t)
 
-        _filtered_matches = sorted(
-            set(filtered_matches), key=lambda x: completions_sorting_key(x[0]))\
-            [:MATCHES_LIMIT]
+        _filtered_matches = sorted(filtered_matches, key=lambda x: completions_sorting_key(x[0]))
 
+        custom_res = [(m, 'custom') for m in self.dispatch_custom_completer(text) or []]
+        
+        _filtered_matches = custom_res or _filtered_matches
+        
+        _filtered_matches = _filtered_matches[:MATCHES_LIMIT]
         _matches = [m[0] for m in _filtered_matches]
         origins = [m[1] for m in _filtered_matches]
 
@@ -2086,7 +2083,7 @@ class IPCompleter(Completer):
                 return s, candidates
             else:
                 return '', ()
-        
+
         # if text does not start with slash
         else:
             return u'', ()
